@@ -26,6 +26,8 @@ enum CommandType
   CMD_GET_AWAY_MESSAGE,
   CMD_ADD_CONTACT,
   CMD_SEND_MESSAGE,
+  CMD_SET_SETTING,
+  CMD_GET_SETTING,
   CMD_QUIT
 };
 
