@@ -31,13 +31,16 @@
 #include "main.h"
 #include "Settings.h"
 
+using std::string;
 using std::ostringstream;
 using std::endl;
 
 using Gtk::Text_Helpers::Context;
 
 AwayMessageDialog::AwayMessageDialog(Gtk::Window *main_window)
-  : m_pos(0), m_count(0), m_main_window(main_window)
+  : m_main_window(main_window),
+    m_close_button("Close"),
+    m_pos(0), m_count(0)
 {
 
   set_title("Away Messages");
@@ -46,8 +49,8 @@ AwayMessageDialog::AwayMessageDialog(Gtk::Window *main_window)
   m_awaytext.set_word_wrap(true);
   
   icqclient.messageack.connect( slot(this,&AwayMessageDialog::messageack_cb) );
-
   button_release_event.connect(slot(this,&AwayMessageDialog::button_press_cb));
+  m_close_button.clicked.connect( slot(this, &AwayMessageDialog::close_cb) );
 
   Gtk::VBox *box = manage( new Gtk::VBox(false) );
 
@@ -57,7 +60,8 @@ AwayMessageDialog::AwayMessageDialog(Gtk::Window *main_window)
   hbox->pack_start(m_awaytext, true, true, 0);
   hbox->pack_start(*scrollbar, false);
   
-  box->pack_end(*hbox);
+  box->pack_start(*hbox, true, true);
+  box->pack_start(m_close_button, false);
 
   add( *box );
   box->show_all();
@@ -66,7 +70,7 @@ AwayMessageDialog::AwayMessageDialog(Gtk::Window *main_window)
 
 AwayMessageDialog::~AwayMessageDialog() { }
 
-gint AwayMessageDialog::delete_event_impl(GdkEventAny *ev) {
+gint AwayMessageDialog::delete_event_impl(GdkEventAny *) {
   hide();
   return true;
 }
@@ -75,23 +79,22 @@ gint AwayMessageDialog::button_press_cb(GdkEventButton *ev) {
   Gtk::Adjustment *adj;
   gfloat val;
 
-  if( ev->button != 4 && ev->button != 5 ) {
-    hide();
-    return true;
-  }
-  
   adj = m_awaytext.get_vadjustment();
   val = adj->get_value();
   if( ev->button == 4 ) {
     val -= adj->get_page_increment();
   }
-  else if( ev->button = 5 ) {
+  else if( ev->button == 5 ) {
     val += adj->get_page_increment();
   }
   adj->set_value( val );
   return true;
 }
 
+void AwayMessageDialog::close_cb() {
+  hide();
+}
+
 void AwayMessageDialog::messageack_cb(ICQ2000::MessageEvent *ev) {
   if (ev->getType() != ICQ2000::MessageEvent::AwayMessage) return;
   if (!ev->isFinished()) return;
@@ -111,6 +114,8 @@ void AwayMessageDialog::messageack_cb(ICQ2000::MessageEvent *ev) {
 
   ICQ2000::ContactRef c = ev->getContact();
 
+  m_awaytext.freeze();
+  
   if (++m_count == 20) {
     m_awaytext.delete_text(0,m_pos);
     m_pos = m_awaytext.get_length();
@@ -138,7 +143,7 @@ void AwayMessageDialog::messageack_cb(ICQ2000::MessageEvent *ev) {
   ostringstream ostr;
   ostr << format_time( ev->getTime() ) << " "
        << c->getAlias() << endl;
-  m_awaytext.freeze();
+
   m_awaytext.insert( header_context, ostr.str());
   if (ev->isDelivered()) {
     m_awaytext.insert( normal_context, aev->getAwayMessage());
