@@ -1,4 +1,4 @@
-/* $Id: ContactListView.cpp,v 1.38 2002/04/05 15:27:42 bugcreator Exp $
+/* $Id: ContactListView.cpp,v 1.41 2002/07/21 00:23:37 bugcreator Exp $
  * 
  * Copyright (C) 2001 Barnaby Gray <barnaby@beedesign.co.uk>.
  *
@@ -46,10 +46,10 @@ using ICQ2000::ContactRef;
 
 ContactListView::ContactListView(IckleGUI& gui, MessageQueue& mq)
   : CList(2),
-    m_single_click(false),
-    m_check_away_click(false),
+    m_message_queue(mq),
     m_gui(gui),
-    m_message_queue(mq)
+    m_single_click(false),
+    m_check_away_click(false)
 {
   column(0).set_title("S");
   column(0).set_width(15);
@@ -158,6 +158,7 @@ int ContactListView::status_order (ICQ2000::Status s)
     case ICQ2000::STATUS_NA:           return 6;
     case ICQ2000::STATUS_OFFLINE:      return 7;
   }
+  return 0;
 }
 
 void ContactListView::clear() {
@@ -201,7 +202,7 @@ gint ContactListView::key_press_event_impl(GdkEventKey *ev) {
     row( rows().size()-1 ).select();
     moveto( rows().size()-1, 0 );
   }
-  else if ( isalpha(key) && ev->state == 0) {
+  else if ( isalnum(key) && !(ev->state & GDK_CONTROL_MASK) && !(ev->state & GDK_MOD1_MASK)) {
     start_iter = row_iter;
     ++row_iter;
     if (row_iter == rows().end()) row_iter = rows().begin();
@@ -328,7 +329,7 @@ void ContactListView::update_row(const ContactRef& c) {
   RowData *rp = (RowData*)(*row).get_data();
   rp->status = c->getStatus();
   rp->msgs = 0;
-  ImageLoader *p;
+  Gtk::ImageLoader *p;
 
   rp->msgs = m_message_queue.get_contact_size(c);
 
