@@ -51,10 +51,6 @@
 # include "ControlHandler.h"
 #endif
 
-using SigC::slot;
-
-using Gtk::Connection;
-
 class IckleClient : public SigC::Object {
 #ifdef CONTROL_SOCKET
   friend class ControlHandler;
@@ -82,8 +78,8 @@ class IckleClient : public SigC::Object {
   std::map<unsigned int, std::string> m_settingsmap; 
   std::map<unsigned int, History *> m_histmap;
 
-  std::map<int, Connection> m_sockets;
-  Connection poll_server_cnt;
+  std::map<int, Gtk::Connection> m_sockets;
+  Gtk::Connection poll_server_cnt;
 
   void processCommandLine(int argc, char* argv[]);
   void usageInstructions(const char* progname);
@@ -100,7 +96,7 @@ class IckleClient : public SigC::Object {
   void saveContact(ICQ2000::ContactRef c, const std::string& s, bool self);
 
   void event_system(const std::string& s, ICQ2000::ContactRef c, time_t t);
-  gint idle_connect_cb(ICQ2000::Status s);
+  gint idle_connect_cb(ICQ2000::Status s, bool inv);
   MessageEvent* convert_libicq2000_event(ICQ2000::MessageEvent *ev);
 
   void SignalLog(ICQ2000::LogEvent::LogType type, const std::string& msg);
@@ -109,13 +105,14 @@ class IckleClient : public SigC::Object {
 
   std::string get_unique_historyname() throw (std::runtime_error);
   
-  void check_pid_file();
   bool mkdir_BASE_DIR();
 
  public:
   IckleClient(int argc, char* argv[]);
   ~IckleClient();
   
+  void init();
+  bool check_pid_file();
   void quit();
 
   // -- Callbacks for libICQ2000 --
