@@ -1,4 +1,4 @@
-/* $Id: IckleGUI.cpp,v 1.56 2002/04/19 15:46:23 bugcreator Exp $
+/* $Id: IckleGUI.cpp,v 1.62 2002/07/21 00:23:37 bugcreator Exp $
  *
  * Copyright (C) 2001 Barnaby Gray <barnaby@beedesign.co.uk>.
  *
@@ -26,6 +26,7 @@
 #include "PromptDialog.h"
 #include "Icons.h"
 #include "AuthRespDialog.h"
+#include "ResendDialog.h"
 
 #include <libicq2000/Client.h>
 
@@ -35,8 +36,10 @@
 
 #include "gtkspell.h"
 
+using std::string;
 using std::map;
 using std::ostringstream;
+using std::endl;
 
 using SigC::bind;
 
@@ -44,11 +47,11 @@ using ICQ2000::ContactRef;
 
 IckleGUI::IckleGUI(MessageQueue& mq)
   :  m_message_queue(mq),
+     m_status(ICQ2000::STATUS_OFFLINE),
+     m_invisible(false),
      m_top_vbox(false),
      m_contact_scroll(),
      m_contact_list(*this, mq),
-     m_status(ICQ2000::STATUS_OFFLINE),
-     m_invisible(false),
      m_away_message( this ),
      m_exiting(false)
 {
@@ -57,6 +60,8 @@ IckleGUI::IckleGUI(MessageQueue& mq)
   icqclient.contactlist.connect(slot(this,&IckleGUI::contactlist_cb));
   icqclient.self_contact_status_change_signal.connect(slot(this,&IckleGUI::self_status_change_cb));
   icqclient.self_contact_userinfo_change_signal.connect(slot(this,&IckleGUI::self_userinfo_change_cb));
+  icqclient.connecting.connect(slot(this,&IckleGUI::connecting_cb));
+  icqclient.disconnected.connect(slot(this,&IckleGUI::disconnected_cb));
 
   // -- MessageQueue callbacks
   m_message_queue.added.connect(slot(this,&IckleGUI::queue_added_cb));
@@ -184,7 +189,7 @@ void IckleGUI::queue_added_cb(MessageEvent *ev) {
   set_ickle_title();
 }
 
-void IckleGUI::queue_removed_cb(MessageEvent *ev) {
+void IckleGUI::queue_removed_cb(MessageEvent *) {
   // update ickle title/icon
   set_ickle_title();
 }
@@ -204,18 +209,7 @@ void IckleGUI::messageack_cb(ICQ2000::MessageEvent *ev) {
     if (icq != NULL &&
 	(ev->getDeliveryFailureReason() == ICQ2000::MessageEvent::Failed_Occupied
 	 || ev->getDeliveryFailureReason() == ICQ2000::MessageEvent::Failed_DND)) {
-      ostringstream ostr;
-      ostr << "Your message to " << c->getNameAlias()
-	   << " wasn't received as the user is "
-	   << (ev->getDeliveryFailureReason() == ICQ2000::MessageEvent::Failed_Occupied
-	       ? "Occupied" : "in Do not Disturb")
-	   << "." << endl << endl
-	   << "Their away message is:" << endl
-	   << icq->getAwayMessage() << endl << endl
-	   << "You should resend the message as 'Urgent' or 'to Contact List'" << endl;
-      PromptDialog *p = new PromptDialog(this, PromptDialog::PROMPT_INFO,
-					 ostr.str(),
-					 false);
+      ResendDialog *p = new ResendDialog(this, icq);
       manage(p);
     }
   }
@@ -254,6 +248,7 @@ void IckleGUI::popup_next_event(const ContactRef& c, History *h) {
     case ICQMessageEvent::SMS:
     case ICQMessageEvent::SMS_Receipt:
     case ICQMessageEvent::EmailEx:
+    case ICQMessageEvent::WebPager:
       popup_messagebox(c, h);
       break;
       
@@ -371,7 +366,7 @@ void IckleGUI::setGeometry(int x, int y, int w, int h)
 
 void IckleGUI::show_impl() {
   set_uposition(geometry_x, geometry_y);
-  get_window().resize(geometry_w, geometry_h);
+  set_default_size(geometry_w, geometry_h);
   Window::show_impl();
 }
 
@@ -456,7 +451,7 @@ void IckleGUI::self_status_change_cb(ICQ2000::StatusChangeEvent *ev)
   set_ickle_title();
 }
 
-void IckleGUI::self_userinfo_change_cb(ICQ2000::UserInfoChangeEvent *ev)
+void IckleGUI::self_userinfo_change_cb(ICQ2000::UserInfoChangeEvent *)
 {
   // update window title & icon
   set_ickle_title();
@@ -728,3 +723,13 @@ void IckleGUI::exit_cb() {
   exit.emit ();
   destroy ();
 }
+
+void IckleGUI::connecting_cb(ICQ2000::ConnectingEvent *) {
+  m_status_menu.connecting();
+}
+
+void IckleGUI::disconnected_cb(ICQ2000::DisconnectedEvent *)
+{
+  // ensure StatusMenu is set back to offline, ie. for when connecting fails
+  m_status_menu.set_status(ICQ2000::STATUS_OFFLINE, icqclient.getInvisibleWanted());
+}
