@@ -1,4 +1,4 @@
-/* $Id: IckleGUI.h,v 1.40 2002/04/19 15:46:23 bugcreator Exp $
+/* $Id: IckleGUI.h,v 1.42 2002/07/20 18:14:13 barnabygray Exp $
  * 
  * The 'looks' part of Ickle (the view)
  *
@@ -131,7 +131,7 @@ class IckleGUI : public Gtk::Window {
   void already_running_prompt(const std::string& pid_file, unsigned int pid);
 
   void setDisplayTimes(bool d);
-  string getAutoResponse() const;
+  std::string getAutoResponse() const;
   void setAutoResponse(const std::string& ar);
   void setGeometry(int x, int y, int w, int h);
 
@@ -142,6 +142,8 @@ class IckleGUI : public Gtk::Window {
   void messageack_cb(ICQ2000::MessageEvent* ev);
   void self_status_change_cb(ICQ2000::StatusChangeEvent *ev);
   void self_userinfo_change_cb(ICQ2000::UserInfoChangeEvent *ev);
+  void connecting_cb(ICQ2000::ConnectingEvent *ev);
+  void disconnected_cb(ICQ2000::DisconnectedEvent *ev);
 
   // -- MessageQueue callbacks --
   void queue_added_cb(MessageEvent *ev);
