@@ -1,4 +1,4 @@
-/* $Id: MessageBox.cpp,v 1.62 2002/04/25 20:31:48 barnabygray Exp $
+/* $Id: MessageBox.cpp,v 1.70 2002/07/21 00:23:37 bugcreator Exp $
  * 
  * Copyright (C) 2001 Barnaby Gray <barnaby@beedesign.co.uk>.
  *
@@ -41,6 +41,9 @@
 
 #include "PromptDialog.h"
 
+#include "pixmaps/info.xpm"
+#include "pixmaps/delivery.xpm"
+
 using Gtk::Text;
 using Gtk::Text_Helpers::Context;
 using SigC::bind;
@@ -58,22 +61,23 @@ MessageBox::MessageBox(MessageQueue& mq, const ICQ2000::ContactRef& self, const
   : m_self_contact(self),
     m_contact(c),
     m_history(h),
-    m_send_button("Send"), m_close_button("Close"),
+    m_scaleadj(0, 0, 0),
+    m_scale(m_scaleadj),
     m_vbox_top(false,10),
-    m_history_table(2,3,false),
+    m_send_button("Send"), m_close_button("Close"),
+    m_history_vbox(false, 0),
+    m_focus(false),
+    m_pending(false),
     m_sms_count_label("", 0),
     m_sms_count_over(false),
     m_sms_enabled(true),
-    m_scaleadj(0, 0, 0),
-    m_scale(m_scaleadj),
-    m_focus(false),
-    m_pending(false),
-    m_message_queue(mq),
     m_send_normal("Normal", 0),
     m_send_urgent("Urgent", 0),
     m_send_tocontactlist("To Contact List", 0),
-    m_last_ev(NULL)
+    m_last_ev(NULL),
+    m_message_queue(mq)
 {
+  Gtk::Box *history_hbox;
   Gtk::Box *hbox;
 
   set_border_width(10);
@@ -85,14 +89,12 @@ MessageBox::MessageBox(MessageQueue& mq, const ICQ2000::ContactRef& self, const
 
   Gtk::Scrollbar *scrollbar;
   
-  m_history_table.set_usize(400,100);
-  m_history_table.attach(m_history_text, 0, 1, 0, 1, GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-			 GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
-  m_history_text.key_press_event.connect(slot(this,&MessageBox::key_press_cb));
+  history_hbox = manage( new Gtk::HBox() );
 
   // scrollbars
   scrollbar = manage( new Gtk::VScrollbar (*(m_history_text.get_vadjustment())) );
-  m_history_table.attach (*scrollbar, 1, 2, 0, 1, 0, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0);
+  history_hbox->pack_start(m_history_text, true, true);
+  history_hbox->pack_start(*scrollbar, false, false);
 
   // initial scale adjustment
   m_scaleadj.set_lower(0);
@@ -109,13 +111,15 @@ MessageBox::MessageBox(MessageQueue& mq, const ICQ2000::ContactRef& self, const
   m_scale.set_draw_value( false );
   m_scale.set_update_policy(GTK_UPDATE_DELAYED);
   m_scale.set_digits(0);
-  m_history_table.attach( m_scalelabel, 0, 2, 1, 2, GTK_FILL | GTK_EXPAND, GTK_FILL );
-  m_history_table.attach( m_scale, 0, 2, 2, 3, GTK_FILL | GTK_EXPAND, 0 );
+
+  m_history_vbox.pack_start(*history_hbox, true, true);
+  m_history_vbox.pack_start(m_scalelabel, false, false);
+  m_history_vbox.pack_start(m_scale, false, false);
 
   m_history_text.set_editable(false);
   m_history_text.set_word_wrap(true);
 
-  m_pane.pack1(m_history_table, true, false);
+  m_pane.pack1(m_history_vbox, true, false);
 
   // -- bottom pane --
 
@@ -218,15 +222,16 @@ MessageBox::MessageBox(MessageQueue& mq, const ICQ2000::ContactRef& self, const
   
   // -- sending modes --
   
-  hbox = manage( new Gtk::HBox() );
   m_send_urgent.set_group( m_send_normal.group() );
   m_send_tocontactlist.set_group( m_send_normal.group() );
+  if (m_contact->getStatus() == ICQ2000::STATUS_DND
+      || m_contact->getStatus() == ICQ2000::STATUS_OCCUPIED) m_send_tocontactlist.set_active(true);
 
-  hbox->pack_end( m_send_normal, false );
-  hbox->pack_end( m_send_urgent, false );
-  hbox->pack_end( m_send_tocontactlist, false );
+  m_delivery_buttons.pack_end( m_send_normal, false );
+  m_delivery_buttons.pack_end( m_send_urgent, false );
+  m_delivery_buttons.pack_end( m_send_tocontactlist, false );
 
-  pane_vbox->pack_start( *hbox, false );
+  pane_vbox->pack_start( m_delivery_buttons, false );
 
   m_pane.pack2(*pane_vbox, false, false);
 
@@ -237,11 +242,18 @@ MessageBox::MessageBox(MessageQueue& mq, const ICQ2000::ContactRef& self, const
   hbox = manage( new Gtk::HBox() );
 
   Gtk::Toolbar *toolbar = manage( new Gtk::Toolbar() );
+  toolbar->set_usize (-1, 22);
   {
     using namespace Gtk::Toolbar_Helpers;
     ToolList& tl = toolbar->tools();
-    tl.push_back( ToggleElem("User Info", slot( this, &MessageBox::userinfo_toggle_cb ), "Popup User Information Dialog" ) );
+    tl.push_back( ToggleElem( * manage( new Gtk::Pixmap(info_xpm) ),
+			      slot( this, &MessageBox::userinfo_toggle_cb ),
+			      "Popup User Information Dialog" ) );
     m_userinfo_toggle = static_cast<Gtk::ToggleButton*>(tl.back()->get_widget());
+    tl.push_back( ToggleElem( * manage( new Gtk::Pixmap(delivery_xpm) ),
+			      slot( this, &MessageBox::delivery_toggle_cb ),
+			      "Show/Hide Delivery urgency options" ) );
+    m_delivery_toggle = static_cast<Gtk::ToggleButton*>(tl.back()->get_widget());
   }
 
   hbox->pack_start(*toolbar, false);
@@ -287,8 +299,9 @@ MessageBox::MessageBox(MessageQueue& mq, const ICQ2000::ContactRef& self, const
     m_pane.set_position( message_box_pane_position );
   }
   size_allocate.connect( slot(this, &MessageBox::resized_cb) );
+
   /* m_history_table height == pane position */
-  m_history_table.size_allocate.connect( slot(this, &MessageBox::pane_position_changed_cb) );
+  m_history_vbox.size_allocate.connect( slot(this, &MessageBox::pane_position_changed_cb) );
 
   // -- callbacks for libicq2000   --
   m_contact->status_change_signal.connect( slot( this, &MessageBox::status_change_cb ) );
@@ -308,6 +321,7 @@ MessageBox::MessageBox(MessageQueue& mq, const ICQ2000::ContactRef& self, const
   m_scaleadj.set_value( upper );
 
   show_all();
+  m_delivery_buttons.hide_all(); // start hidden
   set_contact_title();
 }
 
@@ -434,7 +448,7 @@ void MessageBox::set_contact_title() {
   }
 }
 
-void MessageBox::contactlist_cb(ICQ2000::ContactListEvent *ev) {
+void MessageBox::contactlist_cb(ICQ2000::ContactListEvent *) {
   if (m_contact->isSMSable()) enable_sms();
   else disable_sms();
 
@@ -543,7 +557,14 @@ void MessageBox::userinfo_toggle_cb() {
   userinfo_dialog.emit( m_userinfo_toggle->get_active() );
 }
 
-void MessageBox::switch_page_cb(Gtk::Notebook_Helpers::Page* p, guint n) {
+void MessageBox::delivery_toggle_cb() {
+  if ( m_delivery_toggle->get_active() )
+    m_delivery_buttons.show_all();
+  else
+    m_delivery_buttons.hide_all();
+}
+
+void MessageBox::switch_page_cb(Gtk::Notebook_Helpers::Page*, guint n) {
   if (n == 0 && m_contact->isICQContact() ) {
     m_message_type = ICQ2000::MessageEvent::Normal;
     m_message_text.grab_focus();
@@ -558,7 +579,7 @@ void MessageBox::switch_page_cb(Gtk::Notebook_Helpers::Page* p, guint n) {
   send_button_update();
 }
 
-void MessageBox::new_entry_cb(History::Entry *ev) {
+void MessageBox::new_entry_cb(History::Entry *) {
   gfloat old_upper = m_scaleadj.get_upper() - m_nr_shown;
   if (old_upper < 0) old_upper = 0;
 
@@ -713,12 +734,21 @@ void MessageBox::display_message(History::Entry &e)
     m_history_text.insert( normal_context, e.message);
     break;
       
+  case ICQ2000::MessageEvent::WebPager:
+    ostr << "[pager] ";
+    m_history_text.insert( header_context, ostr.str());
+    m_history_text.insert( normal_context, e.message);
+    break;
+      
+  default:
+    break;
   }
 
 }
 
 void MessageBox::popup() {
   show_all();
+  if (!m_delivery_toggle->get_active()) m_delivery_buttons.hide_all();
   redraw_history();
 }
 
@@ -791,7 +821,7 @@ string MessageBox::format_time(time_t t) {
   return string(time_str);
 }
 
-gint MessageBox::delete_event_impl(GdkEventAny *ev) {
+gint MessageBox::delete_event_impl(GdkEventAny *) {
   return false;
 }
 
@@ -868,7 +898,7 @@ gint MessageBox::text_button_press_cb(GdkEventButton *b, Text *t) {
   if( b->button == 4 ) {
     val -= adj->get_page_increment();
   }
-  else if( b->button = 5 ) {
+  else if( b->button == 5 ) {
     val += adj->get_page_increment();
   }
   adj->set_value( val );
@@ -889,24 +919,24 @@ void MessageBox::spell_detach()
   gtkspell_detach(GTK_TEXT(m_sms_text.gtkobj()));
 }
 
-void MessageBox::resized_cb(GtkAllocation *allocation) {
+void MessageBox::resized_cb(GtkAllocation *) {
   g_settings.setValue("message_box_width", width());
   g_settings.setValue("message_box_height", height());
 }
 
-void MessageBox::pane_position_changed_cb(GtkAllocation *allocation) {
+void MessageBox::pane_position_changed_cb(GtkAllocation *) {
   /* Pane position is the same as m_history_table.height() */
-  g_settings.setValue("message_box_pane_position", m_history_table.height());
+  g_settings.setValue("message_box_pane_position", m_history_vbox.height());
 }
 
-gint MessageBox::focus_in_event_impl(GdkEventFocus* p0)
+gint MessageBox::focus_in_event_impl(GdkEventFocus*)
 {
   m_focus = true;
   if (m_pending) clear_queue();
   return 0;
 }
 
-gint MessageBox::focus_out_event_impl(GdkEventFocus* p0)
+gint MessageBox::focus_out_event_impl(GdkEventFocus*)
 {
   m_focus = false;
   return 0;
@@ -936,6 +966,7 @@ void MessageBox::clear_queue()
 	      || t == ICQMessageEvent::URL
 	      || t == ICQMessageEvent::SMS
 	      || t == ICQMessageEvent::SMS_Receipt
+	      || t == ICQMessageEvent::WebPager
 	      || t == ICQMessageEvent::EmailEx))
 	m_message_queue.remove_from_queue(curr);
     }
@@ -963,5 +994,9 @@ void MessageBox::queue_removed_cb(MessageEvent *ev)
 
 void MessageBox::status_change_cb(ICQ2000::StatusChangeEvent *ev)
 {
+  // automatically change the send as over - a nice touch :-)
+  if ((ev->getStatus() == ICQ2000::STATUS_DND || ev->getStatus() == ICQ2000::STATUS_OCCUPIED)
+      && !m_send_urgent.get_active()) m_send_tocontactlist.set_active(true);
+
   set_contact_title();
 }
