@@ -38,6 +38,10 @@
 # include <applet-widget.h>
 #endif
 
+using std::string;
+using std::cout;
+using std::endl;
+
 class ICQ2000::Client icqclient;
 
 class Settings g_settings;
@@ -56,6 +60,8 @@ int main(int argc, char* argv[]) {
     g_icons.setDefaultIcons();
     
     IckleClient client(argc,argv);
+    if (!client.check_pid_file()) return -1;
+    client.init();    // finish initialising
 
 #ifdef GNOME_ICKLE
     applet_widget_gtk_main();
@@ -64,7 +70,7 @@ int main(int argc, char* argv[]) {
 #endif 
     return 0;
   }
-  catch( exception &e ) {
+  catch( std::exception &e ) {
     cout << "Exiting abnormally: " << e.what() << endl;
   }
   catch( ... ) {
